# CRIPT Python SDK

**CRIPT** (the _Community Resource for Innovation in Polymer Technology_) is a web-based platform for capturing and sharing polymer data. In addition to a user interface, CRIPT enables programmatic access to the platform through the CRIPT Python SDK.

## Quickstart

### Prerequisites
- Python 3.9+
- Internet access

### Install with pip
```bash
pip install cript
```

## Links
- SDK documentation: https://c-accel-cript.github.io/cript/
- Platform: https://criptapp.org
- Blog: https://blog.criptapp.org